Usage
=====

.. _installation:

Development Installation
------------------------

To install from source in editable mode:

.. code-block:: console

   (.venv) $ git clone git@github.com:jenskutilek/fakelab.git
   (.venv) $ cd fakelab
   (.venv) $ pip install -e .


End-User Installation
---------------------

.. code-block:: console

   (.venv) $ pip install fakelab